@@ -43,6 +43,9 @@ import copy
 import re
 
 from dataclasses import dataclass
+
+from iaswn.iaswn import Iaswn
+
 from musamusa_errors.error_messages import ListOfErrorMessages, MusaMusaError
 
 
@@ -107,7 +110,7 @@ DEFAULT_OPTIONS = {
 
 
 @dataclass
-class Note:
+class Note(Iaswn):
     """
         Note class
 
@@ -119,14 +122,26 @@ class Note:
             o (iterable(None|int, None|int))span
 
         METHODS:
+            o __init__(self, infos=None, span=None)
             o __str__(self)
             o span_ok(self)
     """
-    infos: None
+    def __init__(self,
+                 infos=None,
+                 span=None):
+        """
+            Note.__init__()
+        """
+        Iaswn.__init__(self)
 
-    # span: (span_x0, span_x1) Python text span
-    # span: ( None|int, None|int)
-    span: list
+        self.infos = infos
+
+        # span: (span_x0, span_x1) Python text span
+        # span: ( None|int, None|int)
+        if span is None:
+            self.span = []
+        else:
+            self.span = span
 
     def __str__(self):
         """
@@ -158,7 +173,7 @@ class Note:
         return self.span[0] is not None and self.span[1] is not None
 
 
-class AnnotatedString(dict):
+class AnnotatedString(Iaswn, dict):
     """
         AnnotatedString class
 
@@ -245,6 +260,7 @@ class AnnotatedString(dict):
                     ⋅            regex_name: "shortrange_marker"
                     ⋅                        "longrange_marker"
         """
+        Iaswn.__init__(self)
         dict.__init__(self)
 
         if options:
